Module framing

Module framing 

Structs

BackendMessage
MessageReader
Cancellation-safe backend message reader.

Constants

MAX_MESSAGE_SIZE
Maximum backend message size (1GB) - prevents memory exhaustion from malformed length fields This is more than enough.

Functions

read_backend_message
read_backend_message_into
Read a single backend message, reusing the provided buffer.
write_copy_data
write_copy_done
write_password_message
write_query
write_ssl_request
write_startup_message