Structs
- Backend
Message - Message
Reader - Cancellation-safe backend message reader.
Constants
- MAX_
MESSAGE_ SIZE - Maximum backend message size (1GB) - prevents memory exhaustion from malformed length fields This is more than enough.
Functions
- read_
backend_ message - read_
backend_ message_ into - Read a single backend message, reusing the provided buffer.
- write_
copy_ data - write_
copy_ done - write_
password_ message - write_
query - write_
ssl_ request - write_
startup_ message